CREATE DATABASE IF NOT EXISTS wordpress;
USE wordpress;

###############USER RELATED######################
CREATE TABLE IF NOT EXISTS pema_course (
	courseID int NOT NULL AUTO_INCREMENT,
	courseName VARCHAR(60) NOT NULL,
	UNIQUE (courseName),
	PRIMARY KEY (courseID)
);

CREATE TABLE IF NOT EXISTS pema_group (
	groupID int NOT NULL AUTO_INCREMENT,
	groupScore int,
	courseID int,
	groupName VARCHAR(60) NOT NULL,
	groupDescription TEXT,
	PRIMARY KEY (groupID),
	FOREIGN KEY (courseID) REFERENCES pema_course(courseID)
);

CREATE TABLE IF NOT EXISTS pema_user_has_group (
	userID bigint(20) UNSIGNED,
	groupID int,
	FOREIGN KEY (userID) REFERENCES wp_users(ID),
	FOREIGN KEY (groupID) REFERENCES pema_group(groupID)
);
##############END USER RELATED#########################

##############LAB TEMPLATE RELATED#######################
CREATE TABLE IF NOT EXISTS pema_lab_template (
	templateID int NOT NULL AUTO_INCREMENT,
	templateName VARCHAR(60),
	templateDescription TEXT,
	templateCreated TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
	PRIMARY KEY (templateID)
);

CREATE TABLE IF NOT EXISTS pema_lab_rating (
	lrID int NOT NULL AUTO_INCREMENT,
	templateID int,
	rating int,
	comment TEXT,
	PRIMARY KEY (lrID),
	FOREIGN KEY (templateID) REFERENCES pema_lab_template(templateID)
);

#############TASK RELATED######################
CREATE TABLE IF NOT EXISTS pema_task (
	taskID int NOT NULL AUTO_INCREMENT,
	templateID int,
	topic VARCHAR(60),
	taskName VARCHAR(60) NOT NULL,
	taskDescription TEXT,
	taskCreated TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
	taskDeadline TIMESTAMP,
	PRIMARY KEY (taskID),
	FOREIGN KEY (templateID) REFERENCES pema_lab_template(templateID)
);

CREATE TABLE IF NOT EXISTS pema_task_rating (
	rateID int NOT NULL AUTO_INCREMENT,
	taskID int,
	rating int,
	comment TEXT,
	PRIMARY KEY (rateID),
	FOREIGN KEY (taskID) REFERENCES pema_task(taskID)
);

CREATE TABLE IF NOT EXISTS pema_hint (
	hintID int NOT NULL AUTO_INCREMENT,
	taskID int,
	hintPriority int,
	hintPrice int,
	hintName VARCHAR(60) NOT NULL,
	hintDescription TEXT,
	hintSolution TEXT,
	PRIMARY KEY (hintID),
	FOREIGN KEY (taskID) REFERENCES pema_task(taskID)
);
###############END TASK RELATED#################
###############END LAB TEMPLATE RLATED##########

###############PR GROUP LAB RELATED#############
CREATE TABLE IF NOT EXISTS pema_lab (
	labID int NOT NULL AUTO_INCREMENT,
	groupID int,
	templateID int,
	labAnswermethod VARCHAR(60),
	labStart TIMESTAMP,
	labEnd TIMESTAMP,
	labCreated TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
	PRIMARY KEY (labID),
	FOREIGN KEY (groupID) REFERENCES pema_group(groupID)
);

CREATE TABLE IF NOT EXISTS pema_vm (
	vmID int NOT NULL AUTO_INCREMENT,
	labID int,
	vmCreated TIMESTAMP,
	vmIP VARCHAR(15),
	PRIMARY KEY (vmID),
	FOREIGN KEY (labID) REFERENCES pema_lab(labID)
);
############END PR GROUP LAB RELATED###########

CREATE TABLE IF NOT EXISTS pema_topic (
	topicID int NOT NULL AUTO_INCREMENT,
	topicName VARCHAR(60),
	PRIMARY KEY (topicID)
);

CREATE TABLE IF NOT EXISTS pema_lab_has_topic (
	labID int,
	topicID int,
	FOREIGN KEY (labID) REFERENCES pema_lab(labID),
	FOREIGN KEY (topicID) REFERENCES pema_topic(topicID)
);
